@@ -1,5 +1,4 @@
 from easy_notifyer.handlers import (
-    async_telegram_reporter,
     mailer_reporter,
     telegram_reporter,
 )
@@ -7,14 +6,13 @@ from easy_notifyer.mailer import Mailer
 from easy_notifyer.telegram import Telegram, TelegramAsync
 
 
-__version__ = '0.0.3'
+__version__ = '0.0.4'
 
 
 __all__ = [
     "Mailer",
     "Telegram",
     "TelegramAsync",
-    "async_telegram_reporter",
     "mailer_reporter",
     "telegram_reporter",
 ]
